@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: file-embed
-version: 0.0.9.1
-id: file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
-key: filee_ID0BQq7SkFm2s7BTdE1urr
+version: 0.0.10
+id: file-embed-0.0.10-c7da10dfba0f55c7c135317c0bfb8508
+key: filee_BNyHeBYneTRAp0kIbc1T1P
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -19,10 +19,10 @@ exposed: True
 exposed-modules:
     Data.FileEmbed
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/file-embed-0.0.9.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/file-embed-0.0.9.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/file-embed-0.0.9.1
-hs-libraries: HSfile-embed-0.0.9.1-ID0BQq7SkFm2s7BTdE1urr
+import-dirs: /usr/lib/ghc-7.10.3/site-local/file-embed-0.0.10
+library-dirs: /usr/lib/ghc-7.10.3/site-local/file-embed-0.0.10
+data-dir: /usr/share/arm-linux-ghc-7.10.3/file-embed-0.0.10
+hs-libraries: HSfile-embed-0.0.10-BNyHeBYneTRAp0kIbc1T1P
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
